@@ -19,8 +19,7 @@
 package org.apache.iceberg.arrow.vectorized;
 
 import static org.apache.iceberg.Files.localInput;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
+import static org.assertj.core.api.Assertions.assertThat;
 
 import java.io.File;
 import java.io.IOException;
@@ -86,9 +85,9 @@ import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.types.Types;
 import org.apache.iceberg.util.UUIDUtil;
 import org.assertj.core.api.Assertions;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 /**
  * Test cases for {@link ArrowReader}.
@@ -127,14 +126,17 @@ public class ArrowReaderTest {
           "uuid_nullable",
           "decimal",
           "decimal_nullable");
-
-  @Rule public final TemporaryFolder temp = new TemporaryFolder();
+  @TempDir private File tempDir;
 
   private HadoopTables tables;
-
   private String tableLocation;
   private List<GenericRecord> rowsWritten;
 
+  @BeforeEach
+  public void before() {
+    tableLocation = tempDir.toURI().toString();
+  }
+
   /**
    * Read all rows and columns from the table without any filter. The test asserts that the Arrow
    * {@link VectorSchemaRoot} contains the expected schema and expected vector types. Then the test
@@ -225,7 +227,7 @@ public class ArrowReaderTest {
         numRoots++;
       }
     }
-    assertEquals(0, numRoots);
+    assertThat(numRoots).isZero();
   }
 
   /**
@@ -322,14 +324,14 @@ public class ArrowReaderTest {
       for (ColumnarBatch batch : itr) {
         List<GenericRecord> expectedRows = rowsWritten.subList(rowIndex, rowIndex + numRowsPerRoot);
         VectorSchemaRoot root = batch.createVectorSchemaRootFromVectors();
-        assertEquals(createExpectedArrowSchema(columnSet), root.getSchema());
+        assertThat(root.getSchema()).isEqualTo(createExpectedArrowSchema(columnSet));
         checkAllVectorTypes(root, columnSet);
         checkAllVectorValues(numRowsPerRoot, expectedRows, root, columnSet);
         rowIndex += numRowsPerRoot;
         totalRows += root.getRowCount();
       }
     }
-    assertEquals(expectedTotalRows, totalRows);
+    assertThat(totalRows).isEqualTo(expectedTotalRows);
   }
 
   private void readAndCheckHasNextIsIdempotent(
@@ -349,12 +351,12 @@ public class ArrowReaderTest {
         // Call hasNext() a few extra times.
         // This should not affect the total number of rows read.
         for (int i = 0; i < numExtraCallsToHasNext; i++) {
-          assertTrue(iterator.hasNext());
+          assertThat(iterator).hasNext();
         }
 
         ColumnarBatch batch = iterator.next();
         VectorSchemaRoot root = batch.createVectorSchemaRootFromVectors();
-        assertEquals(createExpectedArrowSchema(columnSet), root.getSchema());
+        assertThat(root.getSchema()).isEqualTo(createExpectedArrowSchema(columnSet));
         checkAllVectorTypes(root, columnSet);
         List<GenericRecord> expectedRows = rowsWritten.subList(rowIndex, rowIndex + numRowsPerRoot);
         checkAllVectorValues(numRowsPerRoot, expectedRows, root, columnSet);
@@ -362,7 +364,7 @@ public class ArrowReaderTest {
         totalRows += root.getRowCount();
       }
     }
-    assertEquals(expectedTotalRows, totalRows);
+    assertThat(totalRows).isEqualTo(expectedTotalRows);
   }
 
   @SuppressWarnings("MethodLength")
@@ -378,8 +380,8 @@ public class ArrowReaderTest {
     }
     Set<String> columnSet = columnNameToIndex.keySet();
 
-    assertEquals(expectedNumRows, batch.numRows());
-    assertEquals(columns.size(), batch.numCols());
+    assertThat(batch.numRows()).isEqualTo(expectedNumRows);
+    assertThat(batch.numCols()).isEqualTo(columns.size());
 
     checkColumnarArrayValues(
         expectedNumRows,
@@ -667,7 +669,7 @@ public class ArrowReaderTest {
   private void writeTable(boolean constantRecords) throws Exception {
     rowsWritten = Lists.newArrayList();
     tables = new HadoopTables();
-    tableLocation = temp.newFolder("test").toString();
+    tableLocation = tempDir.toURI().toString();
 
     Schema schema =
         new Schema(
@@ -871,8 +873,8 @@ public class ArrowReaderTest {
 
   private DataFile writeParquetFile(Table table, List<GenericRecord> records) throws IOException {
     rowsWritten.addAll(records);
-    File parquetFile = temp.newFile();
-    assertTrue(parquetFile.delete());
+    File parquetFile = File.createTempFile("junit", null, tempDir);
+    assertThat(parquetFile.delete()).isTrue();
     FileAppender<GenericRecord> appender =
         Parquet.write(Files.localOutput(parquetFile))
             .schema(table.schema())
@@ -949,7 +951,7 @@ public class ArrowReaderTest {
   private void assertEqualsForField(
       VectorSchemaRoot root, Set<String> columnSet, String columnName, Class<?> expected) {
     if (columnSet.contains(columnName)) {
-      assertEquals(expected, root.getVector(columnName).getClass());
+      assertThat(root.getVector(columnName).getClass()).isEqualTo(expected);
     }
   }
 
@@ -959,7 +961,7 @@ public class ArrowReaderTest {
       List<GenericRecord> expectedRows,
       VectorSchemaRoot root,
       Set<String> columnSet) {
-    assertEquals(expectedNumRows, root.getRowCount());
+    assertThat(root.getRowCount()).isEqualTo(expectedNumRows);
 
     checkVectorValues(
         expectedNumRows,
@@ -1196,7 +1198,7 @@ public class ArrowReaderTest {
       BiFunction<FieldVector, Integer, Object> vectorValueExtractor) {
     if (columnSet.contains(columnName)) {
       FieldVector vector = root.getVector(columnName);
-      assertEquals(expectedNumRows, vector.getValueCount());
+      assertThat(vector.getValueCount()).isEqualTo(expectedNumRows);
       for (int i = 0; i < expectedNumRows; i++) {
         Object expectedValue = expectedValueExtractor.apply(expectedRows, i);
         Object actualValue = vectorValueExtractor.apply(vector, i);
