@@ -111,6 +111,11 @@ class CommitCallbackTransaction implements Transaction {
     return wrapped.expireSnapshots();
   }
 
+  @Override
+  public ManageSnapshots manageSnapshots() {
+    return wrapped.manageSnapshots();
+  }
+
   @Override
   public void commitTransaction() {
     wrapped.commitTransaction();
