@@ -71,6 +71,10 @@ public class ResourcePaths {
         RESTUtil.encodeString(ident.name()));
   }
 
+  public String register(Namespace ns) {
+    return SLASH.join("v1", prefix, "namespaces", RESTUtil.encodeNamespace(ns), "register");
+  }
+
   public String rename() {
     return SLASH.join("v1", prefix, "tables", "rename");
   }
@@ -85,4 +89,8 @@ public class ResourcePaths {
         RESTUtil.encodeString(identifier.name()),
         "metrics");
   }
+
+  public String commitTransaction() {
+    return SLASH.join("v1", prefix, "transactions", "commit");
+  }
 }
