@@ -19,10 +19,12 @@
 package org.apache.iceberg.util;
 
 import java.lang.reflect.Array;
+import java.util.Collections;
 import java.util.List;
 import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import java.util.stream.LongStream;
+import org.apache.iceberg.relocated.com.google.common.primitives.Longs;
 
 public class ArrayUtil {
   private ArrayUtil() {}
@@ -59,6 +61,14 @@ public class ArrayUtil {
     }
   }
 
+  public static List<Long> toUnmodifiableLongList(long[] longs) {
+    if (longs != null) {
+      return Collections.unmodifiableList(Longs.asList(longs));
+    } else {
+      return null;
+    }
+  }
+
   public static long[] toLongArray(List<Long> longs) {
     if (longs != null) {
       return longs.stream().mapToLong(v -> v).toArray();
@@ -300,4 +310,14 @@ public class ArrayUtil {
     }
     return Array.newInstance(newArrayComponentType, 1);
   }
+
+  public static boolean isStrictlyAscending(long[] array) {
+    for (int index = 1; index < array.length; index++) {
+      if (array[index] <= array[index - 1]) {
+        return false;
+      }
+    }
+
+    return true;
+  }
 }
