@@ -22,6 +22,7 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.function.Predicate;
 import java.util.stream.Collectors;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
@@ -120,6 +121,26 @@ public class PropertyUtil {
         .collect(Collectors.toMap(e -> e.getKey().replaceFirst(prefix, ""), Map.Entry::getValue));
   }
 
+  /**
+   * Filter the properties map by the provided key predicate.
+   *
+   * @param properties input map
+   * @param keyPredicate predicate to choose keys from input map
+   * @return subset of input map with keys satisfying the predicate
+   */
+  public static Map<String, String> filterProperties(
+      Map<String, String> properties, Predicate<String> keyPredicate) {
+    if (properties == null || properties.isEmpty()) {
+      return Collections.emptyMap();
+    }
+
+    Preconditions.checkArgument(keyPredicate != null, "Invalid key pattern: null");
+
+    return properties.entrySet().stream()
+        .filter(e -> keyPredicate.test(e.getKey()))
+        .collect(Collectors.toMap(Map.Entry::getKey, Map.Entry::getValue));
+  }
+
   public static Map<String, String> applySchemaChanges(
       Map<String, String> properties,
       List<String> deletedColumns,
