@@ -20,13 +20,12 @@ package org.apache.iceberg.rest.responses;
 
 import com.fasterxml.jackson.core.JsonProcessingException;
 import java.util.Map;
-import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.catalog.Namespace;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.rest.RequestResponseTestBase;
-import org.junit.Assert;
-import org.junit.Test;
+import org.assertj.core.api.Assertions;
+import org.junit.jupiter.api.Test;
 
 public class TestGetNamespaceResponse extends RequestResponseTestBase<GetNamespaceResponse> {
 
@@ -67,71 +66,59 @@ public class TestGetNamespaceResponse extends RequestResponseTestBase<GetNamespa
   @Test
   public void testDeserializeInvalidResponse() {
     String jsonNamespaceHasWrongType = "{\"namespace\":\"accounting%1Ftax\",\"properties\":null}";
-    AssertHelpers.assertThrows(
-        "A JSON response with the wrong type for a field should fail to deserialize",
-        JsonProcessingException.class,
-        "Cannot parse string array from non-array",
-        () -> deserialize(jsonNamespaceHasWrongType));
+    Assertions.assertThatThrownBy(() -> deserialize(jsonNamespaceHasWrongType))
+        .as("A JSON response with the wrong type for a field should fail to deserialize")
+        .isInstanceOf(JsonProcessingException.class)
+        .hasMessageContaining("Cannot parse string array from non-array");
 
     String jsonPropertiesHasWrongType =
         "{\"namespace\":[\"accounting\",\"tax\"],\"properties\":[]}";
-    AssertHelpers.assertThrows(
-        "A JSON response with the wrong type for a field should fail to deserialize",
-        JsonProcessingException.class,
-        () -> deserialize(jsonPropertiesHasWrongType));
+    Assertions.assertThatThrownBy(() -> deserialize(jsonPropertiesHasWrongType))
+        .isInstanceOf(JsonProcessingException.class)
+        .hasMessageContaining(
+            "Cannot deserialize value of type `java.util.LinkedHashMap<java.lang.String,java.lang.String>`");
 
     String emptyJson = "{}";
-    AssertHelpers.assertThrows(
-        "An empty JSON request should fail to deserialize after validation",
-        IllegalArgumentException.class,
-        "Invalid namespace: null",
-        () -> deserialize(emptyJson));
+    Assertions.assertThatThrownBy(() -> deserialize(emptyJson))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Invalid namespace: null");
 
     String jsonWithKeysSpelledIncorrectly =
         "{\"namepsace\":[\"accounting\",\"tax\"],\"propertiezzzz\":{\"owner\":\"Hank\"}}";
-    AssertHelpers.assertThrows(
-        "A JSON response with the keys spelled incorrectly should fail to deserialize",
-        IllegalArgumentException.class,
-        "Invalid namespace: null",
-        () -> deserialize(jsonWithKeysSpelledIncorrectly));
+    Assertions.assertThatThrownBy(() -> deserialize(jsonWithKeysSpelledIncorrectly))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Invalid namespace: null");
 
     String nullJson = null;
-    AssertHelpers.assertThrows(
-        "An empty JSON request should fail to deserialize",
-        IllegalArgumentException.class,
-        () -> deserialize(nullJson));
+    Assertions.assertThatThrownBy(() -> deserialize(nullJson))
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("argument \"content\" is null");
   }
 
   @Test
   public void testBuilderDoesNotBuildInvalidRequests() {
-    AssertHelpers.assertThrows(
-        "The builder should not allow using null for the namespace",
-        NullPointerException.class,
-        "Invalid namespace: null",
-        () -> GetNamespaceResponse.builder().withNamespace(null).build());
+    Assertions.assertThatThrownBy(() -> GetNamespaceResponse.builder().withNamespace(null).build())
+        .isInstanceOf(NullPointerException.class)
+        .hasMessage("Invalid namespace: null");
 
-    AssertHelpers.assertThrows(
-        "The builder should not allow passing a null collection of properties",
-        NullPointerException.class,
-        "Invalid properties map: null",
-        () -> GetNamespaceResponse.builder().setProperties(null).build());
+    Assertions.assertThatThrownBy(() -> GetNamespaceResponse.builder().setProperties(null).build())
+        .isInstanceOf(NullPointerException.class)
+        .hasMessage("Invalid properties map: null");
 
     Map<String, String> mapWithNullKey = Maps.newHashMap();
     mapWithNullKey.put(null, "hello");
-    AssertHelpers.assertThrows(
-        "The builder should not allow using null as a key in the properties to set",
-        IllegalArgumentException.class,
-        "Invalid property: null",
-        () -> GetNamespaceResponse.builder().setProperties(mapWithNullKey).build());
+    Assertions.assertThatThrownBy(
+            () -> GetNamespaceResponse.builder().setProperties(mapWithNullKey).build())
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Invalid property: null");
 
     Map<String, String> mapWithMultipleNullValues = Maps.newHashMap();
     mapWithMultipleNullValues.put("a", null);
     mapWithMultipleNullValues.put("b", "b");
-    AssertHelpers.assertThrows(
-        "The builder should not allow using null as a value in the properties to set",
-        IllegalArgumentException.class,
-        "Invalid value for properties [a]: null",
-        () -> GetNamespaceResponse.builder().setProperties(mapWithMultipleNullValues).build());
+    Assertions.assertThatThrownBy(
+            () -> GetNamespaceResponse.builder().setProperties(mapWithMultipleNullValues).build())
+        .isInstanceOf(IllegalArgumentException.class)
+        .hasMessage("Invalid value for properties [a]: null");
   }
 
   @Override
@@ -149,8 +136,8 @@ public class TestGetNamespaceResponse extends RequestResponseTestBase<GetNamespa
 
   @Override
   public void assertEquals(GetNamespaceResponse actual, GetNamespaceResponse expected) {
-    Assert.assertEquals("Namespace should be equal", actual.namespace(), expected.namespace());
-    Assert.assertEquals("Properties should be equal", actual.properties(), expected.properties());
+    Assertions.assertThat(actual.namespace()).isEqualTo(expected.namespace());
+    Assertions.assertThat(actual.properties()).isEqualTo(expected.properties());
   }
 
   @Override
