@@ -290,6 +290,13 @@ public class TestLocalScan {
   public void testFilter() {
     Iterable<Record> result = IcebergGenerics.read(sharedTable).where(lessThan("id", 3)).build();
 
+    Assert.assertEquals(
+        "Records should match file 1",
+        Sets.newHashSet(file1FirstSnapshotRecords),
+        Sets.newHashSet(result));
+
+    result = IcebergGenerics.read(sharedTable).where(lessThan("iD", 3)).caseInsensitive().build();
+
     Assert.assertEquals(
         "Records should match file 1",
         Sets.newHashSet(file1FirstSnapshotRecords),
@@ -306,6 +313,7 @@ public class TestLocalScan {
   @Test
   public void testProject() {
     verifyProjectIdColumn(IcebergGenerics.read(sharedTable).select("id").build());
+    verifyProjectIdColumn(IcebergGenerics.read(sharedTable).select("iD").caseInsensitive().build());
   }
 
   private void verifyProjectIdColumn(Iterable<Record> results) {
