@@ -20,6 +20,7 @@ package org.apache.iceberg.flink;
 
 import java.util.Map;
 import org.apache.hadoop.conf.Configuration;
+import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.CatalogProperties;
 import org.apache.iceberg.catalog.Catalog;
 import org.apache.iceberg.hadoop.HadoopCatalog;
@@ -86,11 +87,11 @@ public class TestFlinkCatalogFactory {
     props.put(
         FlinkCatalogFactory.ICEBERG_CATALOG_TYPE, FlinkCatalogFactory.ICEBERG_CATALOG_TYPE_HIVE);
 
-    Assertions.assertThatThrownBy(
-            () -> FlinkCatalogFactory.createCatalogLoader(catalogName, props, new Configuration()))
-        .isInstanceOf(IllegalArgumentException.class)
-        .hasMessageStartingWith(
-            "Cannot create catalog customCatalog, both catalog-type and catalog-impl are set");
+    AssertHelpers.assertThrows(
+        "Should throw when both catalog-type and catalog-impl are set",
+        IllegalArgumentException.class,
+        "both catalog-type and catalog-impl are set",
+        () -> FlinkCatalogFactory.createCatalogLoader(catalogName, props, new Configuration()));
   }
 
   @Test
@@ -98,10 +99,11 @@ public class TestFlinkCatalogFactory {
     String catalogName = "unknownCatalog";
     props.put(FlinkCatalogFactory.ICEBERG_CATALOG_TYPE, "fooType");
 
-    Assertions.assertThatThrownBy(
-            () -> FlinkCatalogFactory.createCatalogLoader(catalogName, props, new Configuration()))
-        .isInstanceOf(UnsupportedOperationException.class)
-        .hasMessageStartingWith("Unknown catalog-type: fooType");
+    AssertHelpers.assertThrows(
+        "Should throw when an unregistered / unknown catalog is set as the catalog factor's`type` setting",
+        UnsupportedOperationException.class,
+        "Unknown catalog-type",
+        () -> FlinkCatalogFactory.createCatalogLoader(catalogName, props, new Configuration()));
   }
 
   public static class CustomHadoopCatalog extends HadoopCatalog {
