@@ -138,7 +138,7 @@ public class TestCompressionSettings {
           resultProperties.get(TableProperties.PARQUET_COMPRESSION));
       Assert.assertEquals(
           TableProperties.PARQUET_COMPRESSION_LEVEL_DEFAULT,
-          resultProperties.get(TableProperties.PARQUET_COMPRESSION_DEFAULT_SINCE_1_4_0));
+          resultProperties.get(TableProperties.PARQUET_COMPRESSION_LEVEL_DEFAULT));
     } else {
       Assert.assertEquals(
           initProperties.get(TableProperties.PARQUET_COMPRESSION),
