@@ -22,9 +22,6 @@ import static org.apache.iceberg.orc.ORCSchemaUtil.ICEBERG_ID_ATTRIBUTE;
 import static org.apache.iceberg.orc.ORCSchemaUtil.ICEBERG_REQUIRED_ATTRIBUTE;
 import static org.apache.iceberg.types.Types.NestedField.optional;
 import static org.apache.iceberg.types.Types.NestedField.required;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
 
 import java.util.Collections;
 import java.util.List;
@@ -37,7 +34,7 @@ import org.apache.iceberg.types.TypeUtil;
 import org.apache.iceberg.types.Types;
 import org.apache.orc.TypeDescription;
 import org.assertj.core.api.Assertions;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class TestORCSchemaUtil {
 
@@ -65,7 +62,8 @@ public class TestORCSchemaUtil {
   @Test
   public void testRoundtripConversionPrimitive() {
     TypeDescription orcSchema = ORCSchemaUtil.convert(new Schema(SUPPORTED_PRIMITIVES.fields()));
-    assertEquals(SUPPORTED_PRIMITIVES, ORCSchemaUtil.convert(orcSchema).asStruct());
+    Assertions.assertThat(ORCSchemaUtil.convert(orcSchema).asStruct())
+        .isEqualTo(SUPPORTED_PRIMITIVES);
   }
 
   @Test
@@ -191,7 +189,8 @@ public class TestORCSchemaUtil {
                                     Types.ListType.ofRequired(
                                         1250, nestedStructTypeForStruct))))))));
     TypeDescription orcSchema = ORCSchemaUtil.convert(expectedSchema);
-    assertEquals(expectedSchema.asStruct(), ORCSchemaUtil.convert(orcSchema).asStruct());
+    Assertions.assertThat(ORCSchemaUtil.convert(orcSchema).asStruct())
+        .isEqualTo(expectedSchema.asStruct());
   }
 
   @Test
@@ -213,16 +212,18 @@ public class TestORCSchemaUtil {
             optional(3, "c", Types.DecimalType.of(15, 2)));
 
     TypeDescription newOrcSchema = ORCSchemaUtil.buildOrcProjection(evolveSchema, orcSchema);
-    assertEquals(3, newOrcSchema.getChildren().size());
-    assertEquals(1, newOrcSchema.findSubtype("a").getId());
-    assertEquals(TypeDescription.Category.LONG, newOrcSchema.findSubtype("a").getCategory());
-    assertEquals(2, newOrcSchema.findSubtype("b").getId());
-    assertEquals(TypeDescription.Category.DOUBLE, newOrcSchema.findSubtype("b").getCategory());
+    Assertions.assertThat(newOrcSchema.getChildren()).hasSize(3);
+    Assertions.assertThat(newOrcSchema.findSubtype("a").getId()).isEqualTo(1);
+    Assertions.assertThat(newOrcSchema.findSubtype("a").getCategory())
+        .isEqualTo(TypeDescription.Category.LONG);
+    Assertions.assertThat(newOrcSchema.findSubtype("b").getId()).isEqualTo(2);
+    Assertions.assertThat(newOrcSchema.findSubtype("b").getCategory())
+        .isEqualTo(TypeDescription.Category.DOUBLE);
     TypeDescription decimalC = newOrcSchema.findSubtype("c");
-    assertEquals(3, decimalC.getId());
-    assertEquals(TypeDescription.Category.DECIMAL, decimalC.getCategory());
-    assertEquals(15, decimalC.getPrecision());
-    assertEquals(2, decimalC.getScale());
+    Assertions.assertThat(decimalC.getId()).isEqualTo(3);
+    Assertions.assertThat(decimalC.getCategory()).isEqualTo(TypeDescription.Category.DECIMAL);
+    Assertions.assertThat(decimalC.getPrecision()).isEqualTo(15);
+    Assertions.assertThat(decimalC.getScale()).isEqualTo(2);
   }
 
   @Test
@@ -267,7 +268,9 @@ public class TestORCSchemaUtil {
                 5,
                 "mapCol",
                 Types.MapType.ofOptional(3, 4, Types.StringType.get(), Types.BooleanType.get())));
-    assertEquals("Schemas must match.", expectedSchema.asStruct(), icebergSchema.asStruct());
+    Assertions.assertThat(icebergSchema.asStruct())
+        .as("Schemas must match.")
+        .isEqualTo(expectedSchema.asStruct());
 
     TypeDescription structCol = TypeDescription.createStruct();
     structCol.setAttribute(ICEBERG_ID_ATTRIBUTE, "7");
@@ -301,7 +304,9 @@ public class TestORCSchemaUtil {
                     required(6, "doubleCol", Types.DoubleType.get())
                     // Skipped mapCol2 since value has no Iceberg ID
                     )));
-    assertEquals("Schemas must match.", expectedSchema2.asStruct(), icebergSchema2.asStruct());
+    Assertions.assertThat(icebergSchema2.asStruct())
+        .as("Schemas must match.")
+        .isEqualTo(expectedSchema2.asStruct());
   }
 
   @Test
@@ -322,13 +327,15 @@ public class TestORCSchemaUtil {
             optional(4, "listCol", Types.ListType.ofOptional(40, Types.DoubleType.get())));
 
     TypeDescription orcSchema = ORCSchemaUtil.removeIds(ORCSchemaUtil.convert(schema));
-    assertFalse("Should not have Ids", ORCSchemaUtil.hasIds(orcSchema));
+    Assertions.assertThat(ORCSchemaUtil.hasIds(orcSchema)).as("Should not have Ids").isFalse();
 
     TypeDescription map2Col =
         TypeDescription.createMap(TypeDescription.createString(), TypeDescription.createBinary());
     map2Col.setAttribute(ICEBERG_ID_ATTRIBUTE, "4");
     orcSchema.addField("map2Col", map2Col);
-    assertTrue("Should have Ids after adding one type with Id", ORCSchemaUtil.hasIds(orcSchema));
+    Assertions.assertThat(ORCSchemaUtil.hasIds(orcSchema))
+        .as("Should have Ids after adding one type with Id")
+        .isTrue();
   }
 
   @Test
@@ -396,9 +403,10 @@ public class TestORCSchemaUtil {
         ORCSchemaUtil.applyNameMapping(
             ORCSchemaUtil.removeIds(typeDescriptionWithIds), nameMapping);
 
-    assertTrue(
-        "TypeDescription schemas should be equal, including IDs",
-        equalsWithIds(typeDescriptionWithIds, typeDescriptionWithIdsFromNameMapping));
+    Assertions.assertThat(
+            equalsWithIds(typeDescriptionWithIds, typeDescriptionWithIdsFromNameMapping))
+        .as("TypeDescription schemas should be equal, including IDs")
+        .isTrue();
   }
 
   @Test
@@ -504,14 +512,16 @@ public class TestORCSchemaUtil {
     longField.setAttribute(ICEBERG_ID_ATTRIBUTE, "40");
     expected.addField("long_r40", longField);
 
-    assertTrue(
-        "ORC Schema must have the same structure, but one has Iceberg IDs",
-        typeDescriptionWithIdsFromNameMapping.equals(fileSchema, false));
+    Assertions.assertThat(typeDescriptionWithIdsFromNameMapping.equals(fileSchema, false))
+        .as("ORC Schema must have the same structure, but one has Iceberg IDs")
+        .isTrue();
 
     TypeDescription projectedOrcSchema =
         ORCSchemaUtil.buildOrcProjection(mappingSchema, typeDescriptionWithIdsFromNameMapping);
-    assertTrue(
-        "Schema should be the prunned by projection", equalsWithIds(expected, projectedOrcSchema));
+
+    Assertions.assertThat(equalsWithIds(expected, projectedOrcSchema))
+        .as("Schema should be the prunned by projection")
+        .isTrue();
   }
 
   private static boolean equalsWithIds(TypeDescription first, TypeDescription second) {
