@@ -18,21 +18,22 @@
  */
 package org.apache.iceberg.spark.source;
 
+import java.io.IOException;
+import java.io.UncheckedIOException;
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
-import java.util.function.Supplier;
 import java.util.stream.Collectors;
+import org.apache.iceberg.CombinedScanTask;
+import org.apache.iceberg.FileScanTask;
 import org.apache.iceberg.PartitionField;
-import org.apache.iceberg.PartitionScanTask;
 import org.apache.iceberg.PartitionSpec;
-import org.apache.iceberg.Scan;
-import org.apache.iceberg.ScanTask;
-import org.apache.iceberg.ScanTaskGroup;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.Snapshot;
 import org.apache.iceberg.Table;
+import org.apache.iceberg.TableScan;
 import org.apache.iceberg.exceptions.ValidationException;
 import org.apache.iceberg.expressions.Binder;
 import org.apache.iceberg.expressions.Evaluator;
@@ -40,67 +41,112 @@ import org.apache.iceberg.expressions.Expression;
 import org.apache.iceberg.expressions.ExpressionUtil;
 import org.apache.iceberg.expressions.Expressions;
 import org.apache.iceberg.expressions.Projections;
-import org.apache.iceberg.metrics.ScanReport;
+import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.spark.Spark3Util;
+import org.apache.iceberg.spark.SparkFilters;
 import org.apache.iceberg.spark.SparkReadConf;
 import org.apache.iceberg.spark.SparkSchemaUtil;
-import org.apache.iceberg.spark.SparkV2Filters;
 import org.apache.iceberg.util.SnapshotUtil;
+import org.apache.iceberg.util.TableScanUtil;
 import org.apache.spark.sql.SparkSession;
 import org.apache.spark.sql.connector.expressions.NamedReference;
-import org.apache.spark.sql.connector.expressions.filter.Predicate;
 import org.apache.spark.sql.connector.read.Statistics;
-import org.apache.spark.sql.connector.read.SupportsRuntimeV2Filtering;
+import org.apache.spark.sql.connector.read.SupportsRuntimeFiltering;
+import org.apache.spark.sql.sources.Filter;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
-    implements SupportsRuntimeV2Filtering {
+class SparkBatchQueryScan extends SparkScan implements SupportsRuntimeFiltering {
 
   private static final Logger LOG = LoggerFactory.getLogger(SparkBatchQueryScan.class);
 
+  private final TableScan scan;
   private final Long snapshotId;
   private final Long startSnapshotId;
   private final Long endSnapshotId;
   private final Long asOfTimestamp;
-  private final String tag;
   private final List<Expression> runtimeFilterExpressions;
 
+  private Set<Integer> specIds = null; // lazy cache of scanned spec IDs
+  private List<FileScanTask> files = null; // lazy cache of files
+  private List<CombinedScanTask> tasks = null; // lazy cache of tasks
+
   SparkBatchQueryScan(
       SparkSession spark,
       Table table,
-      Scan<?, ? extends ScanTask, ? extends ScanTaskGroup<?>> scan,
+      TableScan scan,
       SparkReadConf readConf,
       Schema expectedSchema,
-      List<Expression> filters,
-      Supplier<ScanReport> scanReportSupplier) {
-    super(spark, table, scan, readConf, expectedSchema, filters, scanReportSupplier);
+      List<Expression> filters) {
 
+    super(spark, table, readConf, expectedSchema, filters);
+
+    this.scan = scan;
     this.snapshotId = readConf.snapshotId();
     this.startSnapshotId = readConf.startSnapshotId();
     this.endSnapshotId = readConf.endSnapshotId();
     this.asOfTimestamp = readConf.asOfTimestamp();
-    this.tag = readConf.tag();
     this.runtimeFilterExpressions = Lists.newArrayList();
+
+    if (scan == null) {
+      this.specIds = Collections.emptySet();
+      this.files = Collections.emptyList();
+      this.tasks = Collections.emptyList();
+    }
   }
 
   Long snapshotId() {
     return snapshotId;
   }
 
+  private Set<Integer> specIds() {
+    if (specIds == null) {
+      Set<Integer> specIdSet = Sets.newHashSet();
+      for (FileScanTask file : files()) {
+        specIdSet.add(file.spec().specId());
+      }
+      this.specIds = specIdSet;
+    }
+
+    return specIds;
+  }
+
+  private List<FileScanTask> files() {
+    if (files == null) {
+      try (CloseableIterable<FileScanTask> filesIterable = scan.planFiles()) {
+        this.files = Lists.newArrayList(filesIterable);
+      } catch (IOException e) {
+        throw new UncheckedIOException("Failed to close table scan: " + scan, e);
+      }
+    }
+
+    return files;
+  }
+
   @Override
-  protected Class<PartitionScanTask> taskJavaClass() {
-    return PartitionScanTask.class;
+  protected List<CombinedScanTask> tasks() {
+    if (tasks == null) {
+      CloseableIterable<FileScanTask> splitFiles =
+          TableScanUtil.splitFiles(
+              CloseableIterable.withNoopClose(files()), scan.targetSplitSize());
+      CloseableIterable<CombinedScanTask> scanTasks =
+          TableScanUtil.planTasks(
+              splitFiles, scan.targetSplitSize(), scan.splitLookback(), scan.splitOpenFileCost());
+      tasks = Lists.newArrayList(scanTasks);
+    }
+
+    return tasks;
   }
 
   @Override
   public NamedReference[] filterAttributes() {
     Set<Integer> partitionFieldSourceIds = Sets.newHashSet();
 
-    for (PartitionSpec spec : specs()) {
+    for (Integer specId : specIds()) {
+      PartitionSpec spec = table().specs().get(specId);
       for (PartitionField field : spec.fields()) {
         partitionFieldSourceIds.add(field.sourceId());
       }
@@ -119,38 +165,45 @@ class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
   }
 
   @Override
-  public void filter(Predicate[] predicates) {
-    Expression runtimeFilterExpr = convertRuntimeFilters(predicates);
+  public void filter(Filter[] filters) {
+    Expression runtimeFilterExpr = convertRuntimeFilters(filters);
 
     if (runtimeFilterExpr != Expressions.alwaysTrue()) {
       Map<Integer, Evaluator> evaluatorsBySpecId = Maps.newHashMap();
 
-      for (PartitionSpec spec : specs()) {
+      for (Integer specId : specIds()) {
+        PartitionSpec spec = table().specs().get(specId);
         Expression inclusiveExpr =
             Projections.inclusive(spec, caseSensitive()).project(runtimeFilterExpr);
         Evaluator inclusive = new Evaluator(spec.partitionType(), inclusiveExpr);
-        evaluatorsBySpecId.put(spec.specId(), inclusive);
+        evaluatorsBySpecId.put(specId, inclusive);
       }
 
-      List<PartitionScanTask> filteredTasks =
-          tasks().stream()
+      LOG.info(
+          "Trying to filter {} files using runtime filter {}",
+          files().size(),
+          ExpressionUtil.toSanitizedString(runtimeFilterExpr));
+
+      List<FileScanTask> filteredFiles =
+          files().stream()
               .filter(
-                  task -> {
-                    Evaluator evaluator = evaluatorsBySpecId.get(task.spec().specId());
-                    return evaluator.eval(task.partition());
+                  file -> {
+                    Evaluator evaluator = evaluatorsBySpecId.get(file.spec().specId());
+                    return evaluator.eval(file.file().partition());
                   })
               .collect(Collectors.toList());
 
       LOG.info(
-          "{} of {} task(s) for table {} matched runtime filter {}",
-          filteredTasks.size(),
-          tasks().size(),
-          table().name(),
+          "{}/{} files matched runtime filter {}",
+          filteredFiles.size(),
+          files().size(),
           ExpressionUtil.toSanitizedString(runtimeFilterExpr));
 
       // don't invalidate tasks if the runtime filter had no effect to avoid planning splits again
-      if (filteredTasks.size() < tasks().size()) {
-        resetTasks(filteredTasks);
+      if (filteredFiles.size() < files().size()) {
+        this.specIds = null;
+        this.files = filteredFiles;
+        this.tasks = null;
       }
 
       // save the evaluated filter for equals/hashCode
@@ -160,11 +213,11 @@ class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
 
   // at this moment, Spark can only pass IN filters for a single attribute
   // if there are multiple filter attributes, Spark will pass two separate IN filters
-  private Expression convertRuntimeFilters(Predicate[] predicates) {
+  private Expression convertRuntimeFilters(Filter[] filters) {
     Expression runtimeFilterExpr = Expressions.alwaysTrue();
 
-    for (Predicate predicate : predicates) {
-      Expression expr = SparkV2Filters.convert(predicate);
+    for (Filter filter : filters) {
+      Expression expr = SparkFilters.convert(filter);
       if (expr != null) {
         try {
           Binder.bind(expectedSchema().asStruct(), expr, caseSensitive());
@@ -173,7 +226,7 @@ class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
           LOG.warn("Failed to bind {} to expected schema, skipping runtime filter", expr, e);
         }
       } else {
-        LOG.warn("Unsupported runtime filter {}", predicate);
+        LOG.warn("Unsupported runtime filter {}", filter);
       }
     }
 
@@ -182,7 +235,7 @@ class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
 
   @Override
   public Statistics estimateStatistics() {
-    if (scan() == null) {
+    if (scan == null) {
       return estimateStatistics(null);
 
     } else if (snapshotId != null) {
@@ -194,14 +247,6 @@ class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
       Snapshot snapshot = table().snapshot(snapshotIdAsOfTime);
       return estimateStatistics(snapshot);
 
-    } else if (branch() != null) {
-      Snapshot snapshot = table().snapshot(branch());
-      return estimateStatistics(snapshot);
-
-    } else if (tag != null) {
-      Snapshot snapshot = table().snapshot(tag);
-      return estimateStatistics(snapshot);
-
     } else {
       Snapshot snapshot = table().currentSnapshot();
       return estimateStatistics(snapshot);
@@ -209,7 +254,6 @@ class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
   }
 
   @Override
-  @SuppressWarnings("checkstyle:CyclomaticComplexity")
   public boolean equals(Object o) {
     if (this == o) {
       return true;
@@ -221,38 +265,34 @@ class SparkBatchQueryScan extends SparkPartitioningAwareScan<PartitionScanTask>
 
     SparkBatchQueryScan that = (SparkBatchQueryScan) o;
     return table().name().equals(that.table().name())
-        && Objects.equals(branch(), that.branch())
-        && readSchema().equals(that.readSchema()) // compare Spark schemas to ignore field ids
-        && filterExpressions().toString().equals(that.filterExpressions().toString())
+        && readSchema().equals(that.readSchema())
+        && // compare Spark schemas to ignore field ids
+        filterExpressions().toString().equals(that.filterExpressions().toString())
         && runtimeFilterExpressions.toString().equals(that.runtimeFilterExpressions.toString())
         && Objects.equals(snapshotId, that.snapshotId)
         && Objects.equals(startSnapshotId, that.startSnapshotId)
         && Objects.equals(endSnapshotId, that.endSnapshotId)
-        && Objects.equals(asOfTimestamp, that.asOfTimestamp)
-        && Objects.equals(tag, that.tag);
+        && Objects.equals(asOfTimestamp, that.asOfTimestamp);
   }
 
   @Override
   public int hashCode() {
     return Objects.hash(
         table().name(),
-        branch(),
         readSchema(),
         filterExpressions().toString(),
         runtimeFilterExpressions.toString(),
         snapshotId,
         startSnapshotId,
         endSnapshotId,
-        asOfTimestamp,
-        tag);
+        asOfTimestamp);
   }
 
   @Override
   public String toString() {
     return String.format(
-        "IcebergScan(table=%s, branch=%s, type=%s, filters=%s, runtimeFilters=%s, caseSensitive=%s)",
+        "IcebergScan(table=%s, type=%s, filters=%s, runtimeFilters=%s, caseSensitive=%s)",
         table(),
-        branch(),
         expectedSchema().asStruct(),
         filterExpressions(),
         runtimeFilterExpressions,
