@@ -90,12 +90,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -119,11 +119,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
     String deleteData = "DELETE FROM %s";
     sql(deleteData, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
-    Assert.assertEquals(2L, result);
+
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -185,11 +186,11 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
     String createIceberg = "CREATE TABLE %s (id Long, data String) USING iceberg";
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`avro`.`%s`')",
             catalogName, tableName, outputFile.getPath());
-    Assert.assertEquals(1L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(1L, 1L)), result);
 
     List<Object[]> expected = Lists.newArrayList(new Object[] {1L, "a"}, new Object[] {2L, "b"});
 
@@ -240,10 +241,10 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
+    List<Object[]> result =
+        sql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -260,12 +261,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -281,12 +282,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -303,12 +304,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(8L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(8L, 4L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -325,12 +326,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(8L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(8L, 4L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -392,10 +393,10 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
+    List<Object[]> result =
+        sql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
 
-    Assert.assertEquals(8L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(8L, 4L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -412,12 +413,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`', map('id', 1))",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -441,11 +442,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
     String deleteData = "DELETE FROM %s where id = 1";
     sql(deleteData, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`', map('id', 1))",
             catalogName, tableName, fileTableDir.getAbsolutePath());
-    Assert.assertEquals(2L, result);
+
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -494,12 +496,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`', map('date', '2021-01-01'))",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -538,12 +540,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`', map('id', 1))",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -561,12 +563,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`', map('dept', 'hr'))",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(6L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(6L, 3L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -586,12 +588,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`', map('id', 1))",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -609,12 +611,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`', map('dept', 'hr'))",
             catalogName, tableName, fileTableDir.getAbsolutePath());
 
-    Assert.assertEquals(6L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(6L, 3L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -634,12 +636,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '%s', map('naMe', 'John Doe'))",
             catalogName, tableName, sourceTableName);
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     /*
     While we would like to use
@@ -684,12 +686,12 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result =
-        scalarSql(
+    List<Object[]> result =
+        sql(
             "CALL %s.system.add_files('%s', '%s', map('id', 1))",
             catalogName, tableName, sourceTableName);
 
-    Assert.assertEquals(2L, result);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -762,23 +764,23 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result1 =
-        scalarSql(
+    List<Object[]> result1 =
+        sql(
             "CALL %s.system.add_files("
                 + "table => '%s', "
                 + "source_table => '%s', "
                 + "partition_filter => map('id', 1))",
             catalogName, tableName, sourceTableName);
-    Assert.assertEquals(2L, result1);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result1);
 
-    Object result2 =
-        scalarSql(
+    List<Object[]> result2 =
+        sql(
             "CALL %s.system.add_files("
                 + "table => '%s', "
                 + "source_table => '%s', "
                 + "partition_filter => map('id', 2))",
             catalogName, tableName, sourceTableName);
-    Assert.assertEquals(2L, result2);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result2);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -799,7 +801,7 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    scalarSql(
+    sql(
         "CALL %s.system.add_files("
             + "table => '%s', "
             + "source_table => '%s', "
@@ -829,18 +831,18 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result1 =
-        scalarSql(
+    List<Object[]> result1 =
+        sql(
             "CALL %s.system.add_files("
                 + "table => '%s', "
                 + "source_table => '%s', "
                 + "partition_filter => map('id', 1))",
             catalogName, tableName, sourceTableName);
 
-    Assert.assertEquals(2L, result1);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result1);
 
-    Object result2 =
-        scalarSql(
+    List<Object[]> result2 =
+        sql(
             "CALL %s.system.add_files("
                 + "table => '%s', "
                 + "source_table => '%s', "
@@ -848,7 +850,7 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
                 + "check_duplicate_files => false)",
             catalogName, tableName, sourceTableName);
 
-    Assert.assertEquals(2L, result2);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result2);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -868,7 +870,7 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    scalarSql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
+    sql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
 
     AssertHelpers.assertThrows(
         "Should not allow adding duplicate files",
@@ -889,18 +891,18 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object result1 =
-        scalarSql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
-    Assert.assertEquals(2L, result1);
+    List<Object[]> result1 =
+        sql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result1);
 
-    Object result2 =
-        scalarSql(
+    List<Object[]> result2 =
+        sql(
             "CALL %s.system.add_files("
                 + "table => '%s', "
                 + "source_table => '%s',"
                 + "check_duplicate_files => false)",
             catalogName, tableName, sourceTableName);
-    Assert.assertEquals(2L, result2);
+    assertEquals("Procedure output must match", ImmutableList.of(row(2L, 1L)), result2);
 
     assertEquals(
         "Iceberg table contains correct data",
@@ -918,11 +920,11 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
     sql(createIceberg, tableName);
 
     // Empty path based import
-    Object pathResult =
-        scalarSql(
+    List<Object[]> pathResult =
+        sql(
             "CALL %s.system.add_files('%s', '`parquet`.`%s`')",
             catalogName, tableName, fileTableDir.getAbsolutePath());
-    Assert.assertEquals(0L, pathResult);
+    assertEquals("Procedure output must match", ImmutableList.of(row(0L, 0L)), pathResult);
     assertEquals(
         "Iceberg table contains no added data when importing from an empty path",
         emptyQueryResult,
@@ -933,9 +935,9 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
         "CREATE TABLE %s (id Integer, name String, dept String, subdept String) STORED AS parquet";
     sql(createHive, sourceTableName);
 
-    Object tableResult =
-        scalarSql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
-    Assert.assertEquals(0L, tableResult);
+    List<Object[]> tableResult =
+        sql("CALL %s.system.add_files('%s', '%s')", catalogName, tableName, sourceTableName);
+    assertEquals("Procedure output must match", ImmutableList.of(row(0L, 0L)), tableResult);
     assertEquals(
         "Iceberg table contains no added data when importing from an empty table",
         emptyQueryResult,
@@ -957,15 +959,15 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
 
     sql(createIceberg, tableName);
 
-    Object tableResult =
-        scalarSql(
+    List<Object[]> tableResult =
+        sql(
             "CALL %s.system.add_files("
                 + "table => '%s', "
                 + "source_table => '%s', "
                 + "partition_filter => map('id', %d))",
             catalogName, tableName, sourceTableName, emptyPartitionId);
 
-    Assert.assertEquals(0L, tableResult);
+    assertEquals("Procedure output must match", ImmutableList.of(row(0L, 0L)), tableResult);
     assertEquals(
         "Iceberg table contains no added data when importing from an empty table",
         emptyQueryResult,
@@ -1018,7 +1020,7 @@ public class TestAddFilesProcedure extends SparkExtensionsTestBase {
     new StructField("id", DataTypes.IntegerType, true, Metadata.empty()),
     new StructField("name", DataTypes.StringType, true, Metadata.empty()),
     new StructField("ts", DataTypes.DateType, true, Metadata.empty()),
-    new StructField("dept", DataTypes.StringType, true, Metadata.empty())
+    new StructField("dept", DataTypes.StringType, true, Metadata.empty()),
   };
 
   private static java.sql.Date toDate(String value) {
