@@ -57,7 +57,6 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.spark.CommitMetadata;
 import org.apache.iceberg.spark.FileRewriteCoordinator;
 import org.apache.iceberg.spark.SparkWriteConf;
-import org.apache.iceberg.spark.SparkWriteRequirements;
 import org.apache.spark.TaskContext;
 import org.apache.spark.TaskContext$;
 import org.apache.spark.api.java.JavaSparkContext;
@@ -98,9 +97,9 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
   private final Schema writeSchema;
   private final StructType dsSchema;
   private final Map<String, String> extraSnapshotMetadata;
-  private final boolean useFanoutWriter;
-  private final SparkWriteRequirements writeRequirements;
-  private final Map<String, String> writeProperties;
+  private final boolean partitionedFanoutEnabled;
+  private final Distribution requiredDistribution;
+  private final SortOrder[] requiredOrdering;
 
   private boolean cleanupOnAbort = true;
 
@@ -112,7 +111,8 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
       String applicationId,
       Schema writeSchema,
       StructType dsSchema,
-      SparkWriteRequirements writeRequirements) {
+      Distribution requiredDistribution,
+      SortOrder[] requiredOrdering) {
     this.sparkContext = JavaSparkContext.fromSparkContext(spark.sparkContext());
     this.table = table;
     this.writeConf = writeConf;
@@ -126,36 +126,20 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     this.writeSchema = writeSchema;
     this.dsSchema = dsSchema;
     this.extraSnapshotMetadata = writeConf.extraSnapshotMetadata();
-    this.useFanoutWriter = writeConf.useFanoutWriter(writeRequirements);
-    this.writeRequirements = writeRequirements;
+    this.partitionedFanoutEnabled = writeConf.fanoutWriterEnabled();
+    this.requiredDistribution = requiredDistribution;
+    this.requiredOrdering = requiredOrdering;
     this.outputSpecId = writeConf.outputSpecId();
-    this.writeProperties = writeConf.writeProperties();
   }
 
   @Override
   public Distribution requiredDistribution() {
-    Distribution distribution = writeRequirements.distribution();
-    LOG.info("Requesting {} as write distribution for table {}", distribution, table.name());
-    return distribution;
-  }
-
-  @Override
-  public boolean distributionStrictlyRequired() {
-    return false;
+    return requiredDistribution;
   }
 
   @Override
   public SortOrder[] requiredOrdering() {
-    SortOrder[] ordering = writeRequirements.ordering();
-    LOG.info("Requesting {} as write ordering for table {}", ordering, table.name());
-    return ordering;
-  }
-
-  @Override
-  public long advisoryPartitionSizeInBytes() {
-    long size = writeRequirements.advisoryPartitionSize();
-    LOG.info("Requesting {} bytes advisory partition size for table {}", size, table.name());
-    return size;
+    return requiredOrdering;
   }
 
   BatchWrite asBatchAppend() {
@@ -199,8 +183,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         targetFileSize,
         writeSchema,
         dsSchema,
-        useFanoutWriter,
-        writeProperties);
+        partitionedFanoutEnabled);
   }
 
   private void commitOperation(SnapshotUpdate<?> operation, String description) {
@@ -628,9 +611,8 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
     private final long targetFileSize;
     private final Schema writeSchema;
     private final StructType dsSchema;
-    private final boolean useFanoutWriter;
+    private final boolean partitionedFanoutEnabled;
     private final String queryId;
-    private final Map<String, String> writeProperties;
 
     protected WriterFactory(
         Broadcast<Table> tableBroadcast,
@@ -640,17 +622,15 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
         long targetFileSize,
         Schema writeSchema,
         StructType dsSchema,
-        boolean useFanoutWriter,
-        Map<String, String> writeProperties) {
+        boolean partitionedFanoutEnabled) {
       this.tableBroadcast = tableBroadcast;
       this.format = format;
       this.outputSpecId = outputSpecId;
       this.targetFileSize = targetFileSize;
       this.writeSchema = writeSchema;
       this.dsSchema = dsSchema;
-      this.useFanoutWriter = useFanoutWriter;
+      this.partitionedFanoutEnabled = partitionedFanoutEnabled;
       this.queryId = queryId;
-      this.writeProperties = writeProperties;
     }
 
     @Override
@@ -674,7 +654,6 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
               .dataFileFormat(format)
               .dataSchema(writeSchema)
               .dataSparkType(dsSchema)
-              .writeProperties(writeProperties)
               .build();
 
       if (spec.isUnpartitioned()) {
@@ -689,7 +668,7 @@ abstract class SparkWrite implements Write, RequiresDistributionAndOrdering {
             writeSchema,
             dsSchema,
             targetFileSize,
-            useFanoutWriter);
+            partitionedFanoutEnabled);
       }
     }
   }
