@@ -38,6 +38,7 @@ import java.util.stream.Stream;
 import java.util.stream.StreamSupport;
 import org.apache.avro.generic.GenericData;
 import org.apache.avro.generic.GenericRecordBuilder;
+import org.apache.iceberg.AssertHelpers;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.DeleteFile;
 import org.apache.iceberg.Files;
@@ -212,7 +213,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testEntriesTablePartitionedPrune() {
+  public void testEntriesTablePartitionedPrune() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, SPEC);
 
@@ -241,7 +242,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testEntriesTableDataFilePrune() {
+  public void testEntriesTableDataFilePrune() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, PartitionSpec.unpartitioned());
 
@@ -274,7 +275,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testEntriesTableDataFilePruneMulti() {
+  public void testEntriesTableDataFilePruneMulti() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, PartitionSpec.unpartitioned());
 
@@ -312,7 +313,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testFilesSelectMap() {
+  public void testFilesSelectMap() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "entries_test");
     Table table = createTable(tableIdentifier, SCHEMA, PartitionSpec.unpartitioned());
 
@@ -657,7 +658,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testAllMetadataTablesWithStagedCommits() {
+  public void testAllMetadataTablesWithStagedCommits() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "stage_aggregate_table_test");
     Table table = createTable(tableIdentifier, SCHEMA, SPEC);
 
@@ -704,7 +705,8 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
 
     Assert.assertTrue(
         "Stage table should have some snapshots", table.snapshots().iterator().hasNext());
-    Assert.assertNull("Stage table should have null currentSnapshot", table.currentSnapshot());
+    Assert.assertEquals(
+        "Stage table should have null currentSnapshot", null, table.currentSnapshot());
     Assert.assertEquals("Actual results should have two rows", 2, actualAllData.size());
     Assert.assertEquals("Actual results should have two rows", 2, actualAllManifests.size());
     Assert.assertEquals("Actual results should have two rows", 2, actualAllEntries.size());
@@ -1117,16 +1119,17 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
 
     if (!spark.version().startsWith("2")) {
       // Spark 2 isn't able to actually push down nested struct projections so this will not break
-      Assertions.assertThatThrownBy(
-              () ->
-                  spark
-                      .read()
-                      .format("iceberg")
-                      .load(loadLocation(tableIdentifier, "manifests"))
-                      .select("partition_spec_id", "path", "partition_summaries.contains_null")
-                      .collectAsList())
-          .isInstanceOf(SparkException.class)
-          .hasMessageContaining("Cannot project a partial list element struct");
+      AssertHelpers.assertThrows(
+          "Can't prune struct inside list",
+          SparkException.class,
+          "Cannot project a partial list element struct",
+          () ->
+              spark
+                  .read()
+                  .format("iceberg")
+                  .load(loadLocation(tableIdentifier, "manifests"))
+                  .select("partition_spec_id", "path", "partition_summaries.contains_null")
+                  .collectAsList());
     }
 
     Dataset<Row> actualDf =
@@ -1224,8 +1227,8 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
                 snapshotManifest ->
                     manifestRecord(
                         manifestTable, snapshotManifest.first(), snapshotManifest.second()))
-            .sorted(Comparator.comparing(o -> o.get("path").toString()))
             .collect(Collectors.toList());
+    expected.sort(Comparator.comparing(o -> o.get("path").toString()));
 
     Assert.assertEquals("Manifests table should have 5 manifest rows", 5, actual.size());
     for (int i = 0; i < expected.size(); i += 1) {
@@ -1496,16 +1499,15 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
             .orderBy("partition.id")
             .collectAsList();
 
+    List<DataFile> dataFiles = TestHelpers.dataFiles(table);
+    assertDataFilePartitions(dataFiles, Arrays.asList(1, 2, 2));
+
     GenericRecordBuilder builder =
         new GenericRecordBuilder(AvroSchemaUtil.convert(partitionsTable.schema(), "partitions"));
     GenericRecordBuilder partitionBuilder =
         new GenericRecordBuilder(
             AvroSchemaUtil.convert(
                 partitionsTable.schema().findType("partition").asStructType(), "partition"));
-
-    List<DataFile> dataFiles = TestHelpers.dataFiles(table);
-    assertDataFilePartitions(dataFiles, Arrays.asList(1, 2, 2));
-
     List<GenericData.Record> expected = Lists.newArrayList();
     expected.add(
         builder
@@ -1705,6 +1707,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
             .set("position_delete_file_count", 0)
             .set("equality_delete_record_count", 1L) // should be incremented now
             .set("equality_delete_file_count", 1) // should be incremented now
+            .set("spec_id", 0)
             .set("last_updated_at", table.snapshot(eqDeleteCommitId).timestampMillis() * 1000)
             .set("last_updated_snapshot_id", eqDeleteCommitId)
             .build());
@@ -1980,7 +1983,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testFilesTablePartitionId() {
+  public void testFilesTablePartitionId() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "files_test");
     Table table =
         createTable(
@@ -2020,7 +2023,7 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
   }
 
   @Test
-  public void testAllManifestTableSnapshotFiltering() {
+  public void testAllManifestTableSnapshotFiltering() throws Exception {
     TableIdentifier tableIdentifier = TableIdentifier.of("db", "all_manifest_snapshot_filtering");
     Table table = createTable(tableIdentifier, SCHEMA, SPEC);
     Table manifestTable = loadTable(tableIdentifier, "all_manifests");
@@ -2089,8 +2092,8 @@ public abstract class TestIcebergSourceTablesBase extends SparkTestBase {
                 snapshotManifest ->
                     manifestRecord(
                         manifestTable, snapshotManifest.first(), snapshotManifest.second()))
-            .sorted(Comparator.comparing(o -> o.get("path").toString()))
             .collect(Collectors.toList());
+    expected.sort(Comparator.comparing(o -> o.get("path").toString()));
 
     Assert.assertEquals("Manifests table should have 3 manifest rows", 3, actual.size());
     for (int i = 0; i < expected.size(); i += 1) {
