@@ -296,7 +296,14 @@ public class TestPartitionValues {
       Table table = tables.create(SUPPORTED_PRIMITIVES, spec, location.toString());
       table.updateProperties().set(TableProperties.DEFAULT_FILE_FORMAT, format).commit();
 
-      sourceDF.write().format("iceberg").mode(SaveMode.Append).save(location.toString());
+      // disable distribution/ordering and fanout writers to preserve the original ordering
+      sourceDF
+          .write()
+          .format("iceberg")
+          .mode(SaveMode.Append)
+          .option(SparkWriteOptions.USE_TABLE_DISTRIBUTION_AND_ORDERING, "false")
+          .option(SparkWriteOptions.FANOUT_ENABLED, "false")
+          .save(location.toString());
 
       List<Row> actual =
           spark
@@ -369,7 +376,14 @@ public class TestPartitionValues {
       Table table = tables.create(nestedSchema, spec, location.toString());
       table.updateProperties().set(TableProperties.DEFAULT_FILE_FORMAT, format).commit();
 
-      sourceDF.write().format("iceberg").mode(SaveMode.Append).save(location.toString());
+      // disable distribution/ordering and fanout writers to preserve the original ordering
+      sourceDF
+          .write()
+          .format("iceberg")
+          .mode(SaveMode.Append)
+          .option(SparkWriteOptions.USE_TABLE_DISTRIBUTION_AND_ORDERING, "false")
+          .option(SparkWriteOptions.FANOUT_ENABLED, "false")
+          .save(location.toString());
 
       List<Row> actual =
           spark
@@ -481,6 +495,7 @@ public class TestPartitionValues {
             .option(SparkReadOptions.VECTORIZATION_ENABLED, String.valueOf(vectorized))
             .load(baseLocation)
             .select("struct.innerName")
+            .orderBy("struct.innerName")
             .as(Encoders.STRING())
             .collectAsList();
 
